import type { ProxyGraphNode, GraphNode, NormalizedKeyMetadata, FetchResponse, Luvio, ResourceIngest, Snapshot } from '@luvio/engine';
import type { FieldValueRepresentation } from '../generated/types/FieldValueRepresentation';
import type { RecordCreateDefaultRecordRepresentation } from '../generated/types/RecordCreateDefaultRecordRepresentation';
import type { ObjectInfoRepresentation } from '../generated/types/ObjectInfoRepresentation';
import type { RecordInputRepresentation } from '../generated/types/RecordInputRepresentation';
import type { RecordRepresentation, RecordRepresentationNormalized } from '../generated/types/RecordRepresentation';
import type { FieldId } from '../primitives/FieldId';
import type { FieldMapRepresentation, FieldMapRepresentationNormalized } from './fields';
import type { RecordConflictMap } from '../helpers/RecordRepresentation/resolveConflict';
type FieldValueRepresentationValue = FieldValueRepresentation['value'];
export declare const RECORD_REPRESENTATION_ERROR_VERSION = "RECORD_REPRESENTATION_ERROR_VERSION_1";
export declare const RECORD_REPRESENTATION_ERROR_STORE_METADATA_PARAMS: {
    representationName: string;
    namespace: string;
    ttl: number;
    version: string;
};
export interface FieldValueRepresentationLinkState {
    fields: string[];
}
export interface RecordLayoutFragment {
    apiName: RecordRepresentation['apiName'];
    recordTypeId: RecordRepresentation['recordTypeId'];
}
/**
 * A trie data structure representing where each node represents a field on a RecordRepresentation.
 */
export interface RecordFieldTrie {
    name: string;
    children: {
        [name: string]: RecordFieldTrie;
    };
    scalar?: boolean;
    optional?: boolean;
}
export interface TrackedFieldsConfig {
    maxDepth: number;
    onlyFetchLeafNodeIdAndName: boolean;
}
export declare function isGraphNode(node: ProxyGraphNode<unknown> | undefined | null): node is GraphNode<unknown>;
export declare function extractTrackedFields(node: ProxyGraphNode<RecordRepresentationNormalized, RecordRepresentation>, parentFieldName: string, fieldsList?: string[], visitedRecordIds?: Record<string, boolean>, depth?: number): string[];
export declare function extractTrackedFieldsToTrie(recordId: string | NormalizedKeyMetadata, node: ProxyGraphNode<FieldMapRepresentationNormalized, FieldMapRepresentation>, root: RecordFieldTrie, config: TrackedFieldsConfig, visitedRecordIds?: Record<string, boolean>, depth?: number): void;
export declare function isExternalLookupFieldKey(spanningNode: ProxyGraphNode<RecordRepresentationNormalized, RecordRepresentation>): boolean;
export declare function convertTrieToFields(root: RecordFieldTrie): string[];
export declare function convertTrieToFieldsRecursively(root: RecordFieldTrie): string[];
export declare const BLANK_RECORD_FIELDS_TRIE: Readonly<{
    name: "";
    children: {};
}>;
export declare const convertFieldsToTrie: (fields?: string[], isOptional?: boolean, objectName?: string) => RecordFieldTrie;
export declare function getTrackedFields(key: string | NormalizedKeyMetadata, graphNode: ProxyGraphNode<FieldMapRepresentationNormalized, FieldMapRepresentation>, config: TrackedFieldsConfig, fieldsFromConfig?: string[]): string[];
/**
 * Returns a new object that has a list of fields that has been filtered by
 * edited fields. Only contains fields that have been edited from their original
 * values (excluding Id which is always copied over).
 * @param input The RecordInputRepresentation object to filter.
 * @param original The Record object that contains the original field values.
 * @returns RecordInputRepresentation, see the description
 */
export declare function createRecordInputFilteredByEditedFields(input: RecordInputRepresentation, original: RecordRepresentation): RecordInputRepresentation;
/**
 * Returns an object with its data populated from the given record. All fields
 * with values that aren't nested records will be assigned. This object can be
 * used to create a record.
 * @param record The record that contains the source data.
 * @param objectInfo The ObjectInfo corresponding to the apiName on the record.
 *        If provided, only fields that are createable=true (excluding Id) will
 *        be assigned to the object return value.
 * @returns RecordInputRepresentation See description.
 */
export declare function generateRecordInputForCreate(record: RecordRepresentation, objectInfo?: ObjectInfoRepresentation): RecordInputRepresentation;
/**
 * Returns an object with its data populated from the given record. All fields
 * with values that aren't nested records will be assigned. This object can be
 * used to update a record.
 * @param record The record that contains the source data.
 * @param objectInfo The ObjectInfo corresponding to the apiName on the record.
 *        If provided, only fields that are updateable=true (excluding Id) will
 *        be assigned to the object return value.
 * @returns RecordInputRepresentation See description.
 */
export declare function generateRecordInputForUpdate(record: RecordRepresentation, objectInfo?: ObjectInfoRepresentation): RecordInputRepresentation;
/**
 * Gets a new Record Input.
 */
export declare function getRecordInput(): RecordInputRepresentation;
/**
 * Gets a field's value from a record.
 * @param record The record.
 * @param field The qualified API name of the field to return.
 * @returns The field's value (which may be a record in the case of spanning
 *          fields), or undefined if the field isn't found.
 */
export declare function getFieldValue(record: RecordRepresentation, field: FieldId | string): FieldValueRepresentationValue | undefined;
/**
 * Gets a field's display value from a record.
 * @param record The record.
 * @param field The qualified API name of the field to return.
 * @returns The field's display value, or undefined if the field isn't found.
 */
export declare function getFieldDisplayValue(record: RecordRepresentation, field: FieldId | string): FieldValueRepresentationValue | undefined;
export declare function getRecordTypeId(record: RecordRepresentation | RecordLayoutFragment): string;
export declare function markMissingOptionalFields(record: ProxyGraphNode<FieldMapRepresentationNormalized, FieldMapRepresentation>, optionalFields: string[]): void;
export declare function markNulledOutRequiredFields(record: ProxyGraphNode<RecordRepresentationNormalized, RecordRepresentation>, fields: string[]): void;
/**
 * Tells you if an objectApiName is supported by UI API or not.
 * Note: Luvio does not currently support all the entities, the list is limited to UI API supported entities
 * @param objectApiName the object API name from a record.
 * @return True if the provided objectApiName is supported in UI API.
 */
export declare function isSupportedEntity(objectApiName: string): boolean;
/** Return true if a >= b */
export declare function isSuperset(a: string[], b: string[]): boolean;
/** return true if a and b start with the same root name and a contains all nodes in b */
export declare function isSuperRecordFieldTrie(a: RecordFieldTrie, b: RecordFieldTrie): boolean;
export declare function extractRecordIds(record: RecordRepresentation | RecordCreateDefaultRecordRepresentation, luvio: Luvio): {
    [key: string]: boolean;
};
export declare function ingestRecordResponse(luvio: Luvio, response: FetchResponse<RecordRepresentation>, recordId: string, recordIngest: ResourceIngest, conflictMap: RecordConflictMap): Snapshot<RecordRepresentation>;
export {};
